@@ -1,13 +1,13 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: base-orphans
-version: 0.5.1
-id: base-orphans-0.5.1-066f51369735933a8c1cc4e054dd01ca
-key: baseo_6AX85lbMA7QGAoLE1cgr8u
+version: 0.5.3
+id: base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
+key: baseo_4lH3gPOjJvdDgDLhAat0cc
 license: MIT
-copyright: (c) 2012-2015 Simon Hengel,
-           (c) 2014 João Cristóvão,
-           (c) 2015 Ryan Scott
+copyright: (c) 2012-2016 Simon Hengel,
+           (c) 2014-2016 João Cristóvão,
+           (c) 2015-2016 Ryan Scott
 maintainer: Simon Hengel <sol@typeful.net>,
             João Cristóvão <jmacristovao@gmail.com>,
             Ryan Scott <ryan.gl.scott@gmail.com>
@@ -25,10 +25,10 @@ exposed-modules:
     Data.Orphans
 hidden-modules: Data.Orphans.Prelude
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/base-orphans-0.5.1
-hs-libraries: HSbase-orphans-0.5.1-6AX85lbMA7QGAoLE1cgr8u
+import-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/base-orphans-0.5.3
+hs-libraries: HSbase-orphans-0.5.3-4lH3gPOjJvdDgDLhAat0cc
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
